
``rattail.db.auth``
===================

.. automodule:: rattail.db.auth

.. autofunction:: administrator_role

.. autofunction:: authenticated_role

.. autofunction:: guest_role

.. autofunction:: authenticate_user

.. autofunction:: set_user_password

.. autofunction:: has_permission

.. autofunction:: cache_permissions

.. autofunction:: grant_permission

.. autofunction:: revoke_permission
